<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="fi">
<context>
    <name>AmmoSchemeModel</name>
    <message>
        <source>new</source>
        <translation>uusi</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DrawMapWidget</name>
    <message>
        <source>File error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot open file &apos;%1&apos; for writing</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cannot read file &apos;%1&apos;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FreqSpinBox</name>
    <message>
        <source>Never</source>
        <translation>Ei koskaan</translation>
    </message>
    <message numerus="yes">
        <source>Every %1 turn</source>
        <translation>
            <numerusform>Joka vuorolla</numerusform>
            <numerusform>Joka %1:s vuoro</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>GameCFGWidget</name>
    <message>
        <source>Edit weapons</source>
        <translation>Muokkaa aseita</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Illegal ammo scheme</source>
        <translation>Virheellinen ammussuunnitelma</translation>
    </message>
    <message>
        <source>Edit schemes</source>
        <translation>Muokkaa kaavaa</translation>
    </message>
    <message>
        <source>When this option is enabled selecting a game scheme will auto-select a weapon</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game Options</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWChatWidget</name>
    <message>
        <source>%1 *** %2 has been removed from your ignore list</source>
        <translation type="obsolete">%1 *** %2 on poistanut sinut huomiotta jättö-listaltaan</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your ignore list</source>
        <translation type="obsolete">%1 *** %2 on lisännyt sinut huomiotta jättö-listalleen</translation>
    </message>
    <message>
        <source>%1 *** %2 has been removed from your friends list</source>
        <translation type="obsolete">%1 *** %2 on poistanut sinut kaverilistaltaan</translation>
    </message>
    <message>
        <source>%1 *** %2 has been added to your friends list</source>
        <translation type="obsolete">%1 *** %2 on lisännyt sinut kaverilistalleen</translation>
    </message>
    <message>
        <source>%1 has been removed from your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your ignore list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been removed from your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 has been added to your friends list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stylesheet imported from %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Enter %1 if you want to use the current StyleSheet in future, enter %2 to reset!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Couldn&apos;t read %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet discarded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>StyleSheet saved to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to save StyleSheet to %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>%1 is not a valid command!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Kicking %1 ...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWForm</name>
    <message>
        <source>new</source>
        <translation type="obsolete">uusi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Unable to start the server</source>
        <translation>Palvelimen käynnistys ei onnistunut</translation>
    </message>
    <message>
        <source>Cannot save record to file %1</source>
        <translation>Nauhoitetta ei voitu tallentaa tiedostoon %1</translation>
    </message>
    <message>
        <source>Please select record from the list above</source>
        <translation>Ole hyvä ja valitse nauhoite ylläolevasta listasta</translation>
    </message>
    <message>
        <source>DefaultTeam</source>
        <translation>OletusJoukkue</translation>
    </message>
    <message>
        <source>Hedgewars Demo File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Hedgewars Save File</source>
        <comment>File Types</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Demo name:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Game aborted</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Salasana</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="unfinished">Nimimerkkisi %1 on
rekisteröity Hedgewars.org-sivustolla
Ole hyvä ja syötä salasanasi
tai aseta eri nimimerkki asetuksissa:</translation>
    </message>
    <message>
        <source>No password supplied.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="unfinished">Nimimerkki</translation>
    </message>
    <message>
        <source>Some one already uses
 your nickname %1
on the server.
Please pick another nickname:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>No nickname supplied.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWGame</name>
    <message>
        <source>en.txt</source>
        <translation>fi.txt</translation>
    </message>
    <message>
        <source>Cannot open demofile %1</source>
        <translation>Demotiedostoa %1 ei pystytty avaamaan</translation>
    </message>
</context>
<context>
    <name>HWMapContainer</name>
    <message>
        <source>Map</source>
        <translation>Kartta</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Suodatin</translation>
    </message>
    <message>
        <source>All</source>
        <translation>Kaikki</translation>
    </message>
    <message>
        <source>Small</source>
        <translation>Pieni</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Keskikokoinen</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Suuri</translation>
    </message>
    <message>
        <source>Cavern</source>
        <translation>Kaivos</translation>
    </message>
    <message>
        <source>Wacky</source>
        <translation>Sekopäinen</translation>
    </message>
    <message>
        <source>Themes</source>
        <translation>Teemat</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>Small tunnels</source>
        <translation>Pieniä tunneleita</translation>
    </message>
    <message>
        <source>Medium tunnels</source>
        <translation>Keskikokoisia tunneleita</translation>
    </message>
    <message>
        <source>Large tunnels</source>
        <translation>Laajoja tunneleita</translation>
    </message>
    <message>
        <source>Small floating islands</source>
        <translation>Pieniä kelluvia saaria</translation>
    </message>
    <message>
        <source>Medium floating islands</source>
        <translation>Keskikokoisia kelluvia saaria</translation>
    </message>
    <message>
        <source>Large floating islands</source>
        <translation>Suuria kelluvia saaria</translation>
    </message>
    <message>
        <source>Seed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>HWNetServersModel</name>
    <message>
        <source>Title</source>
        <translation>Otsikko</translation>
    </message>
    <message>
        <source>IP</source>
        <translation>IP</translation>
    </message>
    <message>
        <source>Port</source>
        <translation>Portti</translation>
    </message>
</context>
<context>
    <name>HWNewNet</name>
    <message>
        <source>The host was not found. Please check the host name and port settings.</source>
        <translation>Palvelinta ei löydetty. Ole hyvä ja tarkista palvelimen nimi ja porttiasetukset.</translation>
    </message>
    <message>
        <source>Connection refused</source>
        <translation>Yhteys hylätty</translation>
    </message>
    <message>
        <source>Room destroyed</source>
        <translation>Huone tuhottiin</translation>
    </message>
    <message>
        <source>Quit reason: </source>
        <translation>Poistumisssyy: </translation>
    </message>
    <message>
        <source>You got kicked</source>
        <translation>Sinut potkittiin</translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="obsolete">Salasana</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password
or pick another nickname:</source>
        <translation type="obsolete">Nimimerkkisi %1 on
rekisteröity Hedgewars.org:ssa
Ole hyvä ja syötä salasana
tai valitse toinen nimimerkki:</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined the room</source>
        <translation>%1 *** %2 liittyi huoneeseen</translation>
    </message>
    <message>
        <source>%1 *** %2 has joined</source>
        <translation>%1 *** %2 liittyi</translation>
    </message>
    <message>
        <source>%1 *** %2 has left</source>
        <translation>%1 *** %2 poistui</translation>
    </message>
    <message>
        <source>%1 *** %2 has left (%3)</source>
        <translation>%1 *** %2 poistui (%3)</translation>
    </message>
    <message>
        <source>Your nickname %1 is
registered on Hedgewars.org
Please provide your password below
or pick another nickname in game config:</source>
        <translation type="obsolete">Nimimerkkisi %1 on
rekisteröity Hedgewars.org-sivustolla
Ole hyvä ja syötä salasanasi
tai aseta eri nimimerkki asetuksissa:</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation type="obsolete">Nimimerkki</translation>
    </message>
    <message>
        <source>User quit</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>KB</name>
    <message>
        <source>SDL_ttf returned error while rendering text, most propably it is related to the bug in freetype2. It&apos;s recommended to update your freetype lib.</source>
        <translation>SDL_ttf palautti virheen mallintaessaan tekstiä, todennäköisesti syy on freetype2:n ohjelmavirheessä. Freetype-kirjaston päivitys on suosiltetavaa.</translation>
    </message>
</context>
<context>
    <name>PageAdmin</name>
    <message>
        <source>Server message:</source>
        <translation type="obsolete">Palvelimen viesti:</translation>
    </message>
    <message>
        <source>Set message</source>
        <translation type="obsolete">Aseta viesti</translation>
    </message>
    <message>
        <source>Clear Accounts Cache</source>
        <translation>Tyhjennä käyttäjätili-välimuisti</translation>
    </message>
    <message>
        <source>Fetch data</source>
        <translation>Nouda tiedot</translation>
    </message>
    <message>
        <source>Server message for latest version:</source>
        <translation>Palvelimen viesti viimeisimmälle versiolle:</translation>
    </message>
    <message>
        <source>Server message for previous versions:</source>
        <translation>Palvelimen viesti edellisille versioille:</translation>
    </message>
    <message>
        <source>Latest version protocol number:</source>
        <translation>Viimeisin versioprotokollan numero:</translation>
    </message>
    <message>
        <source>MOTD preview:</source>
        <translation>Päivän viestin esikatselu:</translation>
    </message>
    <message>
        <source>Set data</source>
        <translation>Aseta tiedot</translation>
    </message>
</context>
<context>
    <name>PageConnecting</name>
    <message>
        <source>Connecting...</source>
        <translation>Yhdistetään...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="obsolete">Peruuta</translation>
    </message>
</context>
<context>
    <name>PageDrawMap</name>
    <message>
        <source>Undo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Clear</source>
        <translation type="unfinished">Tyhjennä</translation>
    </message>
    <message>
        <source>Load</source>
        <translation type="unfinished">Lataa</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Load drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Save drawn map</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Drawn Maps</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageEditTeam</name>
    <message>
        <source>General</source>
        <translation>Yleiset</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Lisäasetukset</translation>
    </message>
</context>
<context>
    <name>PageGameStats</name>
    <message>
        <source>&lt;p&gt;The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.&lt;/p&gt;</source>
        <translation type="obsolete">&lt;p&gt;Paras laukaus -mitalin voitti &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt; pisteellä&lt;/p&gt;</translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Paras tappaja oli &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;yhdellä&lt;/b&gt; tapolla vuoron aikana&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Paras tappaja oli &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt;:llä tapolla &lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;p&gt;A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.&lt;/p&gt;</source>
        <translation type="obsolete">
            <numerusform>&lt;p&gt;Yhteensä &lt;b&gt;yksi&lt;/b&gt; siili tapettiin tällä kierroksella.&lt;/p&gt;</numerusform>
            <numerusform>&lt;p&gt;Yhteensä &lt;b&gt;%1&lt;/b&gt; siiltä tapettiin tällä kierroksella.&lt;/p&gt;</numerusform>
        </translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Yksityiskohdat</translation>
    </message>
    <message>
        <source>Health graph</source>
        <translation>Terveys-kuvaaja</translation>
    </message>
    <message>
        <source>Ranking</source>
        <translation>Ranking</translation>
    </message>
    <message>
        <source>The best shot award was won by &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation>Paras laukaus-mitalin voitti &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt; vahinkopisteellä.</translation>
    </message>
    <message numerus="yes">
        <source>The best killer is &lt;b&gt;%1&lt;/b&gt; with &lt;b&gt;%2&lt;/b&gt; kills in a turn.</source>
        <translation>
            <numerusform>Paras tappaja on &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt; tapolla</numerusform>
            <numerusform>Paras tappaja on &lt;b&gt;%1&lt;/b&gt; &lt;b&gt;%2&lt;/b&gt; tapolla</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>A total of &lt;b&gt;%1&lt;/b&gt; hedgehog(s) were killed during this round.</source>
        <translation>
            <numerusform>Yhteensä &lt;b&gt;%1&lt;/b&gt; siili tapettiin tämän erän aikana.</numerusform>
            <numerusform>Yhteensä &lt;b&gt;%1&lt;/b&gt; siiltä tapettiin tämän erän aikana.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>(%1 kill)</source>
        <translation type="unfinished">
            <numerusform>(%1 tappo)</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message>
        <source>(%1 kills)</source>
        <translation type="obsolete">(%1 tappoa)</translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; thought it&apos;s good to shoot his own hedgehogs with &lt;b&gt;%2&lt;/b&gt; pts.</source>
        <translation type="unfinished">
            <numerusform>&lt;b&gt;%1&lt;/b&gt; ajatteli että omia siilejä on hyvä vahingoittaa &lt;b&gt;%2&lt;/b&gt; vahinkopisteellä.</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; killed &lt;b&gt;%2&lt;/b&gt; of his own hedgehogs.</source>
        <translation type="unfinished">
            <numerusform>&lt;b&gt;%1&lt;/b&gt; tappoi &lt;b&gt;%2&lt;/b&gt; omaa siiltä.</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>&lt;b&gt;%1&lt;/b&gt; was scared and skipped turn &lt;b&gt;%2&lt;/b&gt; times.</source>
        <translation type="unfinished">
            <numerusform>&lt;b&gt;%1&lt;/b&gt; pelkäsi ja jätti vuoronsa väliin &lt;b&gt;%2&lt;/b&gt; kertaa.</numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageInGame</name>
    <message>
        <source>In game...</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMain</name>
    <message>
        <source>Local Game (Play a game on a single computer)</source>
        <translation>Paikallinen peli (Pelaa yhdellä tietokoneella)</translation>
    </message>
    <message>
        <source>Network Game (Play a game across a network)</source>
        <translation>Verkkopeli (Pelaa verkon yli)</translation>
    </message>
    <message>
        <source>Simply pick the same color as a friend to play together as a team. Each of you will still control his or her own hedgehogs but they&apos;ll win or lose together.</source>
        <comment>Tips</comment>
        <translation>Valitse sama väri kaverisi kanssa pelataksesi samassa joukkueessa. Kumpikin ohjaa omia siilejään, mutta voitatte ja häviätte yhdessä.</translation>
    </message>
    <message>
        <source>Some weapons might do only low damage but they can be a lot more devastating in the right situation. Try to use the Desert Eagle to knock multiple hedgehogs into the water.</source>
        <comment>Tips</comment>
        <translation>Jotkut aseet tekevät vain vähän vahinkoa, mutta voivat olla tuhoisampia oikeassa tilanteessa. Kokeile ampua useampi siili veteen Desert Eaglella.</translation>
    </message>
    <message>
        <source>If you&apos;re unsure what to do and don&apos;t want to waste ammo, skip one round. But don&apos;t let too much time pass as there will be Sudden Death!</source>
        <comment>Tips</comment>
        <translation>Jos et tiedä mitä tehdä etkä halua tuhlata ammuksia, jätä vuoro väliin. Mutta älä anna ajan kulua liikaa koska Äkkikuolema koittaa ennemmin tai myöhemmin!</translation>
    </message>
    <message>
        <source>Want to save ropse? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="obsolete">Haluatko säästää köysiä? Päästä köysi irti ilmassa ja ammu uudelleen. Niin pitkään kun et osu maahan, pääse käyttämään köyden uudelleen kuluttamatta ammuksia!</translation>
    </message>
    <message>
        <source>If you&apos;d like to keep others from using your preferred nickname on the official server, register an account at http://www.hedgewars.org/.</source>
        <comment>Tips</comment>
        <translation>Jos haluat estää muita käyttämästä nimimerkkiäsi virallisella palvelimella, rekisteröi tunnus osoitteessa http://www.hedgewars.org/.</translation>
    </message>
    <message>
        <source>You&apos;re bored of default gameplay? Try one of the missions - they&apos;ll offer different gameplay depending on the one you picked.</source>
        <comment>Tips</comment>
        <translation>Kyllästyttääkö normaali peli? Kokeila tehtäviä - Ne tarjoaa erilaisia pelitapoja riippuen valinnasta.</translation>
    </message>
    <message>
        <source>By default the game will always record the last game played as a demo. Select &apos;Local Game&apos; and pick the &apos;Demos&apos; button on the lower right corner to play or manage them.</source>
        <comment>Tips</comment>
        <translation>Oletuksena viimeisin peli nauhoitetaan demoksi. Valitse &apos;Demot&apos; vasemmasta alakulmasta katsoaksesi ja hallitaksesi niitä.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you&apos;ve got problems, ask on our forums but please don&apos;t expect 24/7 support!</source>
        <comment>Tips</comment>
        <translation>Hedgewars on avointa lähdekoodia ja ilmainen ohjelma jota me luomme vapaa-aikanamme. Jos sinulla on ongelmia, kysy keskustelualueilta apua, mutta älä odota 24/7-tukea!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If you like it, help us with a small donation or contribute your own work!</source>
        <comment>Tips</comment>
        <translation>Hedgewars on avointa lähdekoodia ja ilmainen ohjelma jota me luomme vapaa-aikanamme. Jos pidät siitä, voit auttaa meitä pienellä lahjoituksella tai omaa työllä!</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. Share it with your family and friends as you like!</source>
        <comment>Tips</comment>
        <translation>Hedgewars on avointa lähdekoodia ja ilmainen ohjelma jota me luomme vapaa-aikanamme. Jaa sitä perheesi ja ystäviesi kesken miten haluat!</translation>
    </message>
    <message>
        <source>From time to time there will be official tournaments. Upcoming events will be announced at http://www.hedgewars.org/ some days in advance.</source>
        <comment>Tips</comment>
        <translation>Toisinaan järjestetään virallisia turnauksia. Tulevista tapahtumista tiedotetaan osoitteessa http://www.hedgewars.org/ muutama päivä etukäteen.</translation>
    </message>
    <message>
        <source>Hedgewars is available in many languages. If the translation in your language seems to be missing or outdated, feel free to contact us!</source>
        <comment>Tips</comment>
        <translation>Hedgewars on saatavilla monilla kielillä. Jos oman kielinen käännös puuttuu tai on vanhentunut, ota yhteyttä!</translation>
    </message>
    <message>
        <source>Hedgewars can be run on lots of different operating systems including Microsoft Windows, Mac OS X and Linux.</source>
        <comment>Tips</comment>
        <translation>Hedgewars toimii useilla eri käyttöjärjestelmillä, kuten Microsoft Windowsissa, Mac OS X:ssä ja Linuxissa.</translation>
    </message>
    <message>
        <source>Always remember you&apos;re able to set up your own games in local and network/online play. You&apos;re not restricted to the &apos;Simple Game&apos; option.</source>
        <comment>Tips</comment>
        <translation>Muista että voit aina luoda oman pelisi paikallisesti ja verkkopelissä. Et ole rajoitettu yksinkertaiseen peliin.</translation>
    </message>
    <message>
        <source>While playing you should give yourself a short break at least once an hour.</source>
        <comment>Tips</comment>
        <translation>Pelatessa sinun pitäisi pitää lyhyt tauko vähintään kerran tunnissa.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to enable the low quality mode to improve performance.</source>
        <comment>Tips</comment>
        <translation>Jos näytönohjaimesi ei tarjoa laitteistokiihdytettä OpenGL:ää, kokeile heikennetyn laadun tilaa parantaaksesi suorituskykyä.</translation>
    </message>
    <message>
        <source>We&apos;re open to suggestions and constructive feedback. If you don&apos;t like something or got a great idea, let us know!</source>
        <comment>Tips</comment>
        <translation>Me olemme avoimia ehdotuksille ja rakentavalle palautteelle. Jos et pidä jostain tai sinulla on loistava idea, kerro meille!</translation>
    </message>
    <message>
        <source>Especially while playing online be polite and always remember there might be some minors playing with or against you as well!</source>
        <comment>Tips</comment>
        <translation>Erityisesti verkossa pelattaessa ole kohtelias ja muista että alaikäisiä saattaa myös olla pelaamassa.</translation>
    </message>
    <message>
        <source>Special game modes such as &apos;Vampirism&apos; or &apos;Karma&apos; allow you to develop completely new tactics. Try them in a custom game!</source>
        <comment>Tips</comment>
        <translation>Erityispelimoodit kuten &apos;Vampyrismi&apos; ja &apos;Karma&apos; mahdollistavat kokonaan uusien taktiikoiden kehittämisen. Kokeile niitä muokatussa pelissä!</translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgwars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Windows-versio Hedgewarsista tukee Xfireä. Lisää Hedgewars sen pelilistaan niin kaverisi näkee kun pelaat.</translation>
    </message>
    <message>
        <source>You should never install Hedgewars on computers you don&apos;t own (school, university, work, etc.). Please ask the responsible person instead!</source>
        <comment>Tips</comment>
        <translation>Sinun ei ikinä tulisi asentaa Hedgewarsia tietokoneille joita et omista (koulu, yliopisto, työpaikka jne.). Ole hvä ja pyydä vastuuhenkilöä tekemään se!</translation>
    </message>
    <message>
        <source>Hedgewars can be perfect for short games during breaks. Just ensure you don&apos;t add too many hedgehogs or use an huge map. Reducing time and health might help as well.</source>
        <comment>Tips</comment>
        <translation>Hedgewars voi olla täydellinen peli tauoille. Mutta varmista ettet lisää liian montaa siiltä ta käytä liian suurta karttaa. Ajan ja terveyden vähentäminen voi myös auttaa.</translation>
    </message>
    <message>
        <source>No hedgehogs were harmed in making this game.</source>
        <comment>Tips</comment>
        <translation>Yhtään siiliä ei vahingoitettu tämän pelin tekemisen aikana.</translation>
    </message>
    <message>
        <source>Hedgewars is Open Source and Freeware we create in our spare time. If someone sold you the game, you should try get a refund!</source>
        <comment>Tips</comment>
        <translation>Hedgewars on avointa lähdekoodia ja ilmainen ohjelma jota me luomme vapaa-aikanamme. Jos joku myi sinulle tämän pelin, koita saada rahasi takaisin!</translation>
    </message>
    <message>
        <source>Connect one or more gamepads before starting the game to be able to assign their controls to your teams.</source>
        <comment>Tips</comment>
        <translation>Yhdistä yksi tai useampi peliohjain ennen pelin käynnistämistä liittääksesi niiden kontrollit omaan joukkueeseesi.</translation>
    </message>
    <message>
        <source>Create an account on %1 to keep others from using your most favourite nickname while playing on the official server.</source>
        <comment>Tips</comment>
        <translation>Luo käyttäjätili osoitteessa %1 estääksesi muita käyttämästä suosikkinimimerkkiäsi pelatessasi virallisella palvelimella.</translation>
    </message>
    <message>
        <source>If your graphics card isn&apos;t able to provide hardware accelerated OpenGL, try to update the associated drivers.</source>
        <comment>Tips</comment>
        <translation>Jos näytönohjaimesi ei tue laitteistokiihdytettyä OpenGL:ää, kokeile päivittää ajurit.</translation>
    </message>
    <message>
        <source>There are three different jumps available. Tap [high jump] twice to do a very high/backwards jump.</source>
        <comment>Tips</comment>
        <translation>Hyppyjä on saatavilla kolmea erilaista. Napauta [korkea hyppy]-nappai kahdesti tehdäksesi todella korkean/taaksepäin hypyn.</translation>
    </message>
    <message>
        <source>Afraid of falling off a cliff? Hold down [precise] to turn [left] or [right] without actually moving.</source>
        <comment>Tips</comment>
        <translation>Pelkäätkö että putoat kielekkeeltä? Pidä [tarkkuus]-näppäintä pohjassa kääntyäksesi [vasemmalle] ja [oikealle] liikkumatta.</translation>
    </message>
    <message>
        <source>Some weapons require special strategies or just lots of training, so don&apos;t give up on a particular tool if you miss an enemy once.</source>
        <comment>Tips</comment>
        <translation>Jotkut aseet vaativat erityisstrategiaa tai todella paljon harjoittelua, joten älä anna periksi vaikka et kerran osuisikaan.</translation>
    </message>
    <message>
        <source>Most weapons won&apos;t work once they touch the water. The Homing Bee as well as the Cake are exceptions to this.</source>
        <comment>Tips</comment>
        <translation></translation>
    </message>
    <message>
        <source>The Old Limbuger only causes a small explosion. However the wind affected smelly cloud can poison lots of hogs at once.</source>
        <comment>Tips</comment>
        <translation>Vanha Limburger-juusto aiheuttaa vain pienen räjähdyksen, mutta tuulen vaikuttama hajupilvi voi myrkyttää suuren määrän siiliä kerralla.</translation>
    </message>
    <message>
        <source>The Piano Strike is the most damaging air strike. You&apos;ll lose the hedgehog performing it, so there&apos;s a huge downside as well.</source>
        <comment>Tips</comment>
        <translation>Pianoisku on vahingollisin ilmaisku. Menetät siilen joka sen esittää, joten sillä on myös suuri huono puoli.</translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. It&apos;s turn radius depends on it&apos;s velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Mehiläinen voi olla hankala käyttää. Sen säde riippuu nopeudesta, joten älä käytä sitä täydellä voimalla</translation>
    </message>
    <message>
        <source>Sticky Mines are a perfect tool to create small chain reactions knocking enemy hedgehogs into dire situations ... or water.</source>
        <comment>Tips</comment>
        <translation>Tarttuvat miinat ovat täydellinen työkalu luomaan pieniä ketjureaktioita jotka vie vihollissiilit kauheisiin tilanteisiin...tai veteen.</translation>
    </message>
    <message>
        <source>The Hammer is most effective when used on bridges or girders. Hit hogs will just break through the ground.</source>
        <comment>Tips</comment>
        <translation>Vasara on tehokkaimmillaan silloilla ja palkeilla. Lyödyt siilit iskeytyvät maan läpi.</translation>
    </message>
    <message>
        <source>If you&apos;re stuck behind an enemy hedgehog, use the Hammer to free yourself without getting damaged by an explosion.</source>
        <comment>Tips</comment>
        <translation>Jos olet jumissa vihollissiilin takana, käytä vasaraa vapauttaaksesi itsesi ilman että vahingoidut räjädyksen voimasta.</translation>
    </message>
    <message>
        <source>The Cake&apos;s maximum walking distance depends on the ground it has to pass. Use [attack] to detonate it early.</source>
        <comment>Tips</comment>
        <translation>Kakun pisin mahdollinen kulkumatka riippuu maastosta. Käytä [hyökkäystä] räjäyttääksesi sen aikaisemmin.</translation>
    </message>
    <message>
        <source>The Flame Thrower is a weapon but it can be used for tunnel digging as well.</source>
        <comment>Tips</comment>
        <translation>Liekinheitin on ase mutta sitä voi käyttää myös tunneleiden kaivamiseen.</translation>
    </message>
    <message>
        <source>Use the Incinerating Grenade to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Käytä palavaa kranaattia estämään siilia kulkemasta esimerkiksi tunneleihin ja tasoille.</translation>
    </message>
    <message>
        <source>Want to know who&apos;s behind the game? Click on the Hedgewars logo in the main menu to see the credits.</source>
        <comment>Tips</comment>
        <translation>Haluatko tietää ketkä ovat pelin takana? Klikkaa Hedgewars-logoa päävalikossa nähdäksesi tekijäluettelon.</translation>
    </message>
    <message>
        <source>Like Hedgewars? Become a fan on %1 or follow us on %2!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Feel free to draw your own graves, hats, flags or even maps and themes! But note that you&apos;ll have to share them somewhere to use them online.</source>
        <comment>Tips</comment>
        <translation>Piirrä vapaasti omia hautoja, hattuja, lippuja ja jopa karttoja ja teemoja! Mutta huomaa että sinun pitää jakaa ne jossain käyttääksesi niitä verkossa.</translation>
    </message>
    <message>
        <source>Really want to wear a specific hat? Donate to us and receive an exclusive hat of your choice!</source>
        <comment>Tips</comment>
        <translation>Haluatko todella pitää tiettyä hattua? Lahjoita meille niin saat yksinoikeudella vapaavalintaisen hatun!</translation>
    </message>
    <message>
        <source>Keep your video card drivers up to date to avoid issues playing the game.</source>
        <comment>Tips</comment>
        <translation>Pidä näytönohjaimesi ajurit ajantasall välttääksesi ongelmat pelin pelaamisessa.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;My Documents\Hedgewars&quot;. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation>Löydät Hedgewars-asetustiedostot hakemistosta &quot;Omat tiedostot\Hedgewars&quot;. Ota varmuuskopio tai ota ne mukaasi, mutta älä muokkaa niitä käsin.</translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="obsolete">Löydät Hedgewars-asetustiedostot &quot;Hedgewars&quot;-hakemistosta kotihakemistossasi. Ota varmuuskopio tai ota ne mukaasi, mutta älä muokkaa niitä käsin.</translation>
    </message>
    <message>
        <source>You&apos;re able to associate Hedgewars related files (savegames and demo recordings) with the game to launch them right from your favorite file or internet browser.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Want to save ropes? Release the rope in mid air and then shoot again. As long as you don&apos;t touch the ground you&apos;ll reuse your rope without wasting ammo!</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;Library/Application Support/Hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You can find your Hedgewars configuration files under &quot;.hedgewars&quot; in your home directory. Create backups or take the files with you, but don&apos;t edit them by hand.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Windows version of Hedgewars supports Xfire. Make sure to add Hedgewars to its game list so your friends can see you playing.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Use the Molotov or Flame Thrower to temporary keep hedgehogs from passing terrain such as tunnels or platforms.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>The Homing Bee can be tricky to use. Its turn radius depends on its velocity, so try to not use full power.</source>
        <comment>Tips</comment>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Downloadable Content</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageMultiplayer</name>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
</context>
<context>
    <name>PageNet</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Please select server from the list above</source>
        <translation>Ole hyvä ja valitse palvelin ylläolevasta listasta</translation>
    </message>
</context>
<context>
    <name>PageNetGame</name>
    <message>
        <source>Control</source>
        <translation>Säädöt</translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished">Virhe</translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation type="unfinished">Ole hyvä ja syötä huoneen nimi</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">OK</translation>
    </message>
</context>
<context>
    <name>PageNetType</name>
    <message>
        <source>LAN game</source>
        <translation>Lähiverkkopeli</translation>
    </message>
    <message>
        <source>Official server</source>
        <translation>Virallinen palvelin</translation>
    </message>
</context>
<context>
    <name>PageOptions</name>
    <message>
        <source>New team</source>
        <translation>Uusi joukkue</translation>
    </message>
    <message>
        <source>Edit team</source>
        <translation>Muokkaa joukkuetta</translation>
    </message>
    <message>
        <source>Delete team</source>
        <translation>Poista joukkue</translation>
    </message>
    <message>
        <source>New weapon scheme</source>
        <translation type="obsolete">Uusi ase</translation>
    </message>
    <message>
        <source>Edit weapon scheme</source>
        <translation type="obsolete">Muokkaa asesuunnitelmaa</translation>
    </message>
    <message>
        <source>Delete weapon scheme</source>
        <translation type="obsolete">Poista asesuunnitelma</translation>
    </message>
    <message>
        <source>You can&apos;t edit teams from team selection. Go back to main menu to add, edit or delete teams.</source>
        <translation>Et voi muokata joukkueita joukkuevalinnassa. Mene takaisin päävalikkoon lisätäksesi, muokataksesi tai poistaaksesi joukkueita.</translation>
    </message>
    <message>
        <source>New scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>New weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Edit weapon set</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Delete weapon set</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PagePlayDemo</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Rename dialog</source>
        <translation>Uudelleennimeämis-dialogi</translation>
    </message>
    <message>
        <source>Enter new file name:</source>
        <translation>Syötä uusi tiedostonimi:</translation>
    </message>
    <message>
        <source>Cannot rename to</source>
        <translation>Ei voida uudelleennimetä</translation>
    </message>
    <message>
        <source>Cannot delete file</source>
        <translation>Ei voida poistaa tiedostoa</translation>
    </message>
    <message>
        <source>Please select record from the list</source>
        <translation>Ole hyvä ja valitse nauhoite listasta</translation>
    </message>
</context>
<context>
    <name>PageRoomsList</name>
    <message>
        <source>Create</source>
        <translation>Luo</translation>
    </message>
    <message>
        <source>Join</source>
        <translation>Liity</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Admin features</source>
        <translation>Ylläpitäjän ominaisuudet</translation>
    </message>
    <message>
        <source>Room Name:</source>
        <translation>Huoneen nimi:</translation>
    </message>
    <message>
        <source>This game is in lobby.
You may join and start playing once the game starts.</source>
        <translation>Tämä peli on eteisessä.
Voit liittyä ja alkaa pelaamaan sitten kun peli alkaa.</translation>
    </message>
    <message>
        <source>This game is in progress.
You may join and spectate now but you&apos;ll have to wait for the game to end to start playing.</source>
        <translation>Tämä peli on menossa.
Voit liittyä ja seurata sitä, mutta sinun on odotettava pelin päättymistä päästäksesi pelaamaan.</translation>
    </message>
    <message>
        <source>%1 is the host. He may adjust settings and start the game.</source>
        <translation>%1 on isäntä. Hän voi säätää asetuksia ja aloittaa pelin.</translation>
    </message>
    <message>
        <source>Random Map</source>
        <translation>Satunnainen kartta</translation>
    </message>
    <message>
        <source>Games may be played on precreated or randomized maps.</source>
        <translation>Pelejä voi pelata valmiiksi luoduissa tai satunnaisesti tehdyissä kartoissa.</translation>
    </message>
    <message>
        <source>The Game Scheme defines general options and preferences like Round Time, Sudden Death or Vampirism.</source>
        <translation>Pelikaava määrittelee yleiset asetukset ja säädöt kuten kierrosajan, äkkikuoleman ja vampyrismin.</translation>
    </message>
    <message>
        <source>The Weapon Scheme defines available weapons and their ammunition count.</source>
        <translation>Asesuunnitelma määrittelee saatavilla olevat aseet ja niiden panosmäärät.</translation>
    </message>
    <message numerus="yes">
        <source>There are %1 clients connected to this room.</source>
        <translation>
            <numerusform>Yksi asiakas on liittyneenä tähän huoneeseen</numerusform>
            <numerusform>%1 asiakasta on liittyneenä tähän huoneeseen</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>There are %1 teams participating in this room.</source>
        <translation>
            <numerusform>Tässä huoneessa on osallistuneena yksi joukkue</numerusform>
            <numerusform>Tässä huoneessa on osallistuneena %1 joukkuetta</numerusform>
        </translation>
    </message>
    <message>
        <source>Please enter room name</source>
        <translation>Ole hyvä ja syötä huoneen nimi</translation>
    </message>
    <message>
        <source>Please select room from the list</source>
        <translation>Ole hyvä ja valitse huone listalta</translation>
    </message>
    <message>
        <source>Random Maze</source>
        <translation>Satunnainen sokkelo</translation>
    </message>
    <message>
        <source>State:</source>
        <translation type="obsolete">Tila:</translation>
    </message>
    <message>
        <source>Rules:</source>
        <translation>Säännöt:</translation>
    </message>
    <message>
        <source>Weapons:</source>
        <translation>Aseet:</translation>
    </message>
    <message>
        <source>Search:</source>
        <translation>Haku:</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Varoitus</translation>
    </message>
    <message>
        <source>The game you are trying to join has started.
Do you still want to join the room?</source>
        <translation>Peli johon yrität liittyä on jo alkanut.
Haluatko silti liittyä huoneeseen?</translation>
    </message>
    <message numerus="yes">
        <source>%1 players online</source>
        <translation type="unfinished">
            <numerusform></numerusform>
            <numerusform></numerusform>
        </translation>
    </message>
</context>
<context>
    <name>PageScheme</name>
    <message>
        <source>Defend your fort and destroy the opponents, two team colours max!</source>
        <translation>Puolusta linnaasi ja tuhoa vastustajasi, maksimissaan kaksi joukkueväriä!</translation>
    </message>
    <message>
        <source>Teams will start on opposite sides of the terrain, two team colours max!</source>
        <translation>Joukkueet aloittavat kartan vastakkaisista päistä, maksimissaan kaksi joukkueväriä!</translation>
    </message>
    <message>
        <source>Land can not be destroyed!</source>
        <translation>Maata ei voi tuhota!</translation>
    </message>
    <message>
        <source>Add an indestructable border around the terrain</source>
        <translation type="obsolete">Lisää tuhoutumattomat reunat kartan ympärille</translation>
    </message>
    <message>
        <source>Lower gravity</source>
        <translation>Matalampi painovoima</translation>
    </message>
    <message>
        <source>Assisted aiming with laser sight</source>
        <translation>Lasertähtäimellä avustettu tähtäys</translation>
    </message>
    <message>
        <source>All hogs have a personal forcefield</source>
        <translation>Kaikilla siileillä on oma suojakenttänsä</translation>
    </message>
    <message>
        <source>Enable random mines</source>
        <translation type="obsolete">Lisää miinoja satunnaisesti</translation>
    </message>
    <message>
        <source>Gain 80% of the damage you do back in health</source>
        <translation>Saa 80% aiheuttamastasi vahingosta takaisin omaan terveyteesi</translation>
    </message>
    <message>
        <source>Share your opponents pain, share their damage</source>
        <translation>Jaa vastuastajasi tuska, jaa heidän vahinkonsa</translation>
    </message>
    <message>
        <source>Your hogs are unable to move, put your artillery skills to the test</source>
        <translation>Kaikki siilit ovat liikkumattomia, testaa tykistötaitojasi</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Satunnainen</translation>
    </message>
    <message>
        <source>Seconds</source>
        <translation>Sekuntia</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Uusi</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Order of play is random instead of in room order.</source>
        <translation>Pelaamisjärjestys on satunnainen huoneen järjestyksen sijaan.</translation>
    </message>
    <message>
        <source>Play with a King. If he dies, your side dies.</source>
        <translation>Pelaa kuninkaalla. Jos hän kuolee, sinun jokkueesi häviää.</translation>
    </message>
    <message>
        <source>Take turns placing your hedgehogs before the start of play.</source>
        <translation>Sijoittakaa siilenne vuorotellen ennen pelin alkua.</translation>
    </message>
    <message>
        <source>Ammo is shared between all teams that share a colour.</source>
        <translation>Ammukset ovat yhteiset saman värin kesken.</translation>
    </message>
    <message>
        <source>Disable girders when generating random maps.</source>
        <translation>Kytke palkit pois päältä satunnaisissa kartoissa.</translation>
    </message>
    <message>
        <source>Disable land objects when generating random maps.</source>
        <translation>Poista maaobjektit satunnaisten karttojen luonnissa.</translation>
    </message>
    <message>
        <source>AI respawns on death.</source>
        <translation>Tekoäly syntyy uudelleen kuollessaan.</translation>
    </message>
    <message>
        <source>All (living) hedgehogs are fully restored at the end of turn</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Attacking does not end your turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Weapons are reset to starting values each turn.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Each hedgehog has its own ammo. It does not share with the team.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You will not have to worry about wind anymore.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wind will affect almost everything.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams in each clan take successive turns sharing their turn time.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add an indestructible border around the terrain</source>
        <translation>Lisää tuhoutumattomat reunat kartan ympärille</translation>
    </message>
    <message>
        <source>Add an indestructible border along the bottom</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSelectWeapon</name>
    <message>
        <source>Default</source>
        <translation>Oletus</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>New</source>
        <translation type="unfinished">Uusi</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageSinglePlayer</name>
    <message>
        <source>Simple Game (a quick game against the computer, settings are chosen for you)</source>
        <translation>Yksinkertainen peli (pikapeli tietokonetta vastaan, asetukset valitaan puolestasi)</translation>
    </message>
    <message>
        <source>Multiplayer (play a hotseat game against your friends, or AI teams)</source>
        <translation>Moninpeli (pelaa samalla koneella kavereitasi tai tekoälyä vastaan)</translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions). IN DEVELOPMENT</source>
        <translation type="obsolete">Harjoittelu (Harjoita taitojasi harjoitustasoissa). KEHITYKSEN ALLA</translation>
    </message>
    <message>
        <source>Demos (Watch recorded demos)</source>
        <translation>Demot (Katso nauhoitettuja demoja)</translation>
    </message>
    <message>
        <source>Load (Load a previously saved game)</source>
        <translation>Lataa (Lataa aikaisemmin tallennettu peli)</translation>
    </message>
    <message>
        <source>Campaign Mode (...). IN DEVELOPMENT</source>
        <translation type="obsolete">Kampanja-tila (...). KEHITYS KESKEN</translation>
    </message>
    <message>
        <source>Campaign Mode (...)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Training Mode (Practice your skills in a range of training missions)</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PageTraining</name>
    <message>
        <source>No description available</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Select a mission!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QAction</name>
    <message>
        <source>Kick</source>
        <translation>Potki</translation>
    </message>
    <message>
        <source>Info</source>
        <translation>Tietoja</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Aloita</translation>
    </message>
    <message>
        <source>Restrict Joins</source>
        <translation>Rajoita liittymisiä</translation>
    </message>
    <message>
        <source>Restrict Team Additions</source>
        <translation>Rajoita joukkuelisäyksiä</translation>
    </message>
    <message>
        <source>Ban</source>
        <translation>Anna porttikielto</translation>
    </message>
    <message>
        <source>Follow</source>
        <translation>Seuraa</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Jätä huomiotta</translation>
    </message>
    <message>
        <source>Add friend</source>
        <translation>Lisää kaveriksi</translation>
    </message>
    <message>
        <source>Unignore</source>
        <translation>Ota huomion</translation>
    </message>
    <message>
        <source>Remove friend</source>
        <translation>Poista kaverilistalta</translation>
    </message>
    <message>
        <source>Update</source>
        <translation type="unfinished">Päivitä</translation>
    </message>
</context>
<context>
    <name>QCheckBox</name>
    <message>
        <source>Check for updates at startup</source>
        <translation>Tarkista päivitykset käynnistyksessä</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>Koko ruutu</translation>
    </message>
    <message>
        <source>Frontend fullscreen</source>
        <translation>Koko ruutu käyttöliittymälle</translation>
    </message>
    <message>
        <source>Enable sound</source>
        <translation>Äänet päälle</translation>
    </message>
    <message>
        <source>Enable music</source>
        <translation>Musiikki päälle</translation>
    </message>
    <message>
        <source>Show FPS</source>
        <translation>Näytä FPS</translation>
    </message>
    <message>
        <source>Alternative damage show</source>
        <translation>Vaihtoehtoinen vahingon näyttäminen</translation>
    </message>
    <message>
        <source>Append date and time to record file name</source>
        <translation>Lisää päivämäärä ja aika nauhoitusten tiedostonimeen</translation>
    </message>
    <message>
        <source>Reduced quality</source>
        <translation type="obsolete">Huononnettu laatu</translation>
    </message>
    <message>
        <source>Show ammo menu tooltips</source>
        <translation>Näytä asevalikon vihjeet</translation>
    </message>
    <message>
        <source>Enable frontend sounds</source>
        <translation>Kytke käyttöliittymän äänet päälle</translation>
    </message>
    <message>
        <source>Enable frontend music</source>
        <translation>Kytke käyttöliittymän musiikki päälle</translation>
    </message>
    <message>
        <source>Frontend effects</source>
        <translation>Käyttöliittymän tehosteet</translation>
    </message>
</context>
<context>
    <name>QComboBox</name>
    <message>
        <source>generated map...</source>
        <translation>generoitu kartta...</translation>
    </message>
    <message>
        <source>Human</source>
        <translation>Ihminen</translation>
    </message>
    <message>
        <source>Level</source>
        <translation>Taso</translation>
    </message>
    <message>
        <source>(System default)</source>
        <translation>(Järjestelmän oletus)</translation>
    </message>
    <message>
        <source>generated maze...</source>
        <translation>Generoitu sokkelo...</translation>
    </message>
    <message>
        <source>Mission</source>
        <translation>Tehtävä</translation>
    </message>
    <message>
        <source>Community</source>
        <translation>Yhteisö</translation>
    </message>
    <message>
        <source>Any</source>
        <translation>Mikä tahansa</translation>
    </message>
    <message>
        <source>In lobby</source>
        <translation>Aulassa</translation>
    </message>
    <message>
        <source>In progress</source>
        <translation>Kesken</translation>
    </message>
    <message>
        <source>Default</source>
        <translation type="obsolete">Oletus</translation>
    </message>
    <message>
        <source>Pro mode</source>
        <translation type="obsolete">Pro-tila</translation>
    </message>
    <message>
        <source>Shoppa</source>
        <translation type="obsolete">Shoppa</translation>
    </message>
    <message>
        <source>Basketball</source>
        <translation type="obsolete">Koripallo</translation>
    </message>
    <message>
        <source>Minefield</source>
        <translation type="obsolete">Miinakenttä</translation>
    </message>
    <message>
        <source>Barrel mayhem</source>
        <translation type="obsolete">Tynnyrikaaos</translation>
    </message>
    <message>
        <source>Tunnel hogs</source>
        <translation type="obsolete">Tunnelisiilit</translation>
    </message>
    <message>
        <source>Crazy</source>
        <translation type="obsolete">Sekopäinen</translation>
    </message>
    <message>
        <source>hand drawn map...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disabled</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Side-by-side</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Top-Bottom</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Wiggle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Cyan grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cyan/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Blue grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Blue/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Red/Green grayscale</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Green/Red grayscale</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QGroupBox</name>
    <message>
        <source>Team Members</source>
        <translation>Joukkueen jäsenet</translation>
    </message>
    <message>
        <source>Fort</source>
        <translation>Linnake</translation>
    </message>
    <message>
        <source>Key binds</source>
        <translation>Näppäinasettelut</translation>
    </message>
    <message>
        <source>Teams</source>
        <translation>Joukkueet</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation type="obsolete">Aseet</translation>
    </message>
    <message>
        <source>Net game</source>
        <translation>Verkkopeli</translation>
    </message>
    <message>
        <source>Playing teams</source>
        <translation>Pelaavat joukkueet</translation>
    </message>
    <message>
        <source>Audio/Graphic options</source>
        <translation>Ääni/grafiikka-asetukset</translation>
    </message>
    <message>
        <source>Game Modifiers</source>
        <translation>Pelimuuttujat</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation>Perusasetukset</translation>
    </message>
    <message>
        <source>Team Settings</source>
        <translation>Joukkueasetukset</translation>
    </message>
    <message>
        <source>Misc</source>
        <translation>Muut</translation>
    </message>
    <message>
        <source>Schemes and Weapons</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLabel</name>
    <message>
        <source>Mines Time</source>
        <translation>Miinojen aika</translation>
    </message>
    <message>
        <source>Mines</source>
        <translation>Miinat</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Versio</translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License</source>
        <translation type="obsolete">Tätä ohjelmaa levitetään GNU General Public Licence-lisensisn alla</translation>
    </message>
    <message>
        <source>Developers:</source>
        <translation>Kehittäjät:</translation>
    </message>
    <message>
        <source>Art:</source>
        <translation>Taide:</translation>
    </message>
    <message>
        <source>Sounds:</source>
        <translation>Äänet:</translation>
    </message>
    <message>
        <source>Translations:</source>
        <translation>Käännökset:</translation>
    </message>
    <message>
        <source>Special thanks:</source>
        <translation>Erikoiskiitokset:</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
    <message>
        <source>Host:</source>
        <translation>Palvelin:</translation>
    </message>
    <message>
        <source>Port:</source>
        <translation>Portti:</translation>
    </message>
    <message>
        <source>Net nick</source>
        <translation>Verkkopeli-nimimerkki</translation>
    </message>
    <message>
        <source>Resolution</source>
        <translation>Resoluutio</translation>
    </message>
    <message>
        <source>FPS limit</source>
        <translation>FPS-raja</translation>
    </message>
    <message>
        <source>Server name:</source>
        <translation>Palvelimen nimi:</translation>
    </message>
    <message>
        <source>Server port:</source>
        <translation>Palvelimen portti:</translation>
    </message>
    <message>
        <source>Initial sound volume</source>
        <translation>Alkuperäinen äänten voimakkuus</translation>
    </message>
    <message>
        <source>Damage Modifier</source>
        <translation>Vahinkomuuttuja</translation>
    </message>
    <message>
        <source>Turn Time</source>
        <translation>Vuoron aika</translation>
    </message>
    <message>
        <source>Initial Health</source>
        <translation>Aloitusterveys</translation>
    </message>
    <message>
        <source>Sudden Death Timeout</source>
        <translation>Äkkikuoleman ajastus</translation>
    </message>
    <message>
        <source>Scheme Name:</source>
        <translation>Kaavan nimi:</translation>
    </message>
    <message>
        <source>Crate Drops</source>
        <translation>Laatikkojen pudotukset</translation>
    </message>
    <message>
        <source>Game scheme</source>
        <translation>Pelikaava</translation>
    </message>
    <message>
        <source>% Dud Mines</source>
        <translation>% suutarimiinoja</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Nimi</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tyyppi</translation>
    </message>
    <message>
        <source>Grave</source>
        <translation>Hauta</translation>
    </message>
    <message>
        <source>Flag</source>
        <translation>Lippu</translation>
    </message>
    <message>
        <source>Voice</source>
        <translation>Ääni</translation>
    </message>
    <message>
        <source>Locale</source>
        <translation>Kieli</translation>
    </message>
    <message>
        <source>Restart game to apply</source>
        <translation>Käynnistä peli uudelleen ottaaksesi muutokset käyttöön</translation>
    </message>
    <message>
        <source>Explosives</source>
        <translation>Räjähteet</translation>
    </message>
    <message>
        <source>Tip: </source>
        <translation>Vinkki: </translation>
    </message>
    <message>
        <source>This development build is &apos;work in progress&apos; and may not be compatible with other versions of the game. Some features might be broken or incomplete. Use at your own risk!</source>
        <translation>Tämä kehitysversio on keskeneräinen ja ei välttämättä ole yhteensopiva muiden versioiden kanssa. Jotkut ominaisuudet voivat olla rikki tai kesken. Käytä omalla vastuulla!</translation>
    </message>
    <message>
        <source>Quality</source>
        <translation>Laatu</translation>
    </message>
    <message>
        <source>% Health Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Health in Crates</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Water Rise</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sudden Death Health Decrease</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>% Rope Length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Stereo rendering</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Style</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Scheme</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password</source>
        <translation type="unfinished">Salasana</translation>
    </message>
    <message>
        <source>% Get Away Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>This program is distributed under the GNU General Public License v2</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QLineEdit</name>
    <message>
        <source>unnamed</source>
        <translation>nimetön</translation>
    </message>
    <message>
        <source>hedgehog %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QMainWindow</name>
    <message>
        <source>Hedgewars %1</source>
        <translation>Hedgewars %1</translation>
    </message>
</context>
<context>
    <name>QMessageBox</name>
    <message>
        <source>Network</source>
        <translation>Verkko</translation>
    </message>
    <message>
        <source>Connection to server is lost</source>
        <translation>Yhteys palvelimeen katosi</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Failed to open data directory:
%1
Please check your installation</source>
        <translation>Data-hakemiston avaus epäonnistui:
 %1
Ole hyvä ja tarkista asennuksesi</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
    <message>
        <source>Can not edit default weapon set</source>
        <translation type="obsolete">Oletus-asesettiä ei voi muokata</translation>
    </message>
    <message>
        <source>Can not delete default weapon set</source>
        <translation type="obsolete">Oletus-asesettiä ei voi poistaa</translation>
    </message>
    <message>
        <source>Really delete this weapon set?</source>
        <translation>Haluatko todella poistaa tämän asesetin?</translation>
    </message>
    <message>
        <source>Can not overwrite default weapon set &apos;%1&apos;!</source>
        <translation>Oletusasetussettiä &apos;%1&apos; ei voida ylikirjoittaa!</translation>
    </message>
    <message>
        <source>All file associations have been set.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>File association failed.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Teams</source>
        <translation type="unfinished">Joukkueet</translation>
    </message>
    <message>
        <source>Really delete this team?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Schemes</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default scheme &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Really delete this game scheme?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Can not delete default weapon set &apos;%1&apos;!</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Cannot create directory %1</source>
        <translation>Hakemiston %1 luonti epäonnistui</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Nickname</source>
        <translation>Nimimerkki</translation>
    </message>
    <message>
        <source>Please enter your nickname</source>
        <translation>Ole hyvä ja syötä nimimerkkisi</translation>
    </message>
</context>
<context>
    <name>QPushButton</name>
    <message>
        <source>default</source>
        <translation>oletus</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>OK</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Peruuta</translation>
    </message>
    <message>
        <source>Start server</source>
        <translation>Käynnistä palvelin</translation>
    </message>
    <message>
        <source>Connect</source>
        <translation>Yhdistä</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Päivitä</translation>
    </message>
    <message>
        <source>Specify</source>
        <translation>Määritä</translation>
    </message>
    <message>
        <source>Start</source>
        <translation>Käynnistä</translation>
    </message>
    <message>
        <source>Go!</source>
        <translation>Aloita!</translation>
    </message>
    <message>
        <source>Play demo</source>
        <translation>Toista nauhoite</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Nimeä uudelleen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poista</translation>
    </message>
    <message>
        <source>Load</source>
        <translation>Lataa</translation>
    </message>
    <message>
        <source>Setup</source>
        <translation>Asetukset</translation>
    </message>
    <message>
        <source>Ready</source>
        <translation>Valmis</translation>
    </message>
    <message>
        <source>Random Team</source>
        <translation>Satunnainen joukkue</translation>
    </message>
    <message>
        <source>Associate file extensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>more</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QTableWidget</name>
    <message>
        <source>Room Name</source>
        <translation>Huoneen nimi</translation>
    </message>
    <message>
        <source>C</source>
        <translation>A</translation>
    </message>
    <message>
        <source>T</source>
        <translation>J</translation>
    </message>
    <message>
        <source>Owner</source>
        <translation>Omistaja</translation>
    </message>
    <message>
        <source>Map</source>
        <translation>Kartta</translation>
    </message>
    <message>
        <source>Rules</source>
        <translation>Säännöt</translation>
    </message>
    <message>
        <source>Weapons</source>
        <translation>Aseet</translation>
    </message>
</context>
<context>
    <name>SelWeaponWidget</name>
    <message>
        <source>Weapon set</source>
        <translation>Asesetti</translation>
    </message>
    <message>
        <source>Probabilities</source>
        <translation>Todennäköisyydet</translation>
    </message>
    <message>
        <source>Ammo in boxes</source>
        <translation>Ammukset laatikoissa</translation>
    </message>
    <message>
        <source>Delays</source>
        <translation>Viipeet</translation>
    </message>
    <message>
        <source>new</source>
        <translation type="unfinished">uusi</translation>
    </message>
    <message>
        <source>copy of</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>TCPBase</name>
    <message>
        <source>Error</source>
        <translation>Virhe</translation>
    </message>
    <message>
        <source>Unable to start the server: %1.</source>
        <translation>Palvelinta ei pystytty käynnistämään: %1.</translation>
    </message>
    <message>
        <source>Unable to run engine: %1 (</source>
        <translation>Pelimoottorin ajo epäonnistui: %1 (</translation>
    </message>
</context>
<context>
    <name>ToggleButtonWidget</name>
    <message>
        <source>Vampirism</source>
        <translation>Vampyrismi</translation>
    </message>
    <message>
        <source>Karma</source>
        <translation>Karma</translation>
    </message>
    <message>
        <source>Artillery</source>
        <translation>Tykistö</translation>
    </message>
    <message>
        <source>Fort Mode</source>
        <translation>Linnoitustila</translation>
    </message>
    <message>
        <source>Divide Teams</source>
        <translation>Jaa joukkueet</translation>
    </message>
    <message>
        <source>Solid Land</source>
        <translation>Tuhoutumaton maa</translation>
    </message>
    <message>
        <source>Add Border</source>
        <translation>Lisää reunat</translation>
    </message>
    <message>
        <source>Low Gravity</source>
        <translation>Matala painovoima</translation>
    </message>
    <message>
        <source>Laser Sight</source>
        <translation>Lasertähtäin</translation>
    </message>
    <message>
        <source>Invulnerable</source>
        <translation>Vahingoittumaton</translation>
    </message>
    <message>
        <source>Add Mines</source>
        <translation type="obsolete">Lisää miinat</translation>
    </message>
    <message>
        <source>Random Order</source>
        <translation>Satunnainen Järjestys</translation>
    </message>
    <message>
        <source>King</source>
        <translation>Kuningas</translation>
    </message>
    <message>
        <source>Place Hedgehogs</source>
        <translation>Sijoita siilet</translation>
    </message>
    <message>
        <source>Clan Shares Ammo</source>
        <translation>Saman väriset jakavat ammukset</translation>
    </message>
    <message>
        <source>Disable Girders</source>
        <translation>Ei palkkeja</translation>
    </message>
    <message>
        <source>Disable Land Objects</source>
        <translation>Ei maaobjekteja</translation>
    </message>
    <message>
        <source>AI Survival Mode</source>
        <translation>Tekoäly selviytymistila</translation>
    </message>
    <message>
        <source>Reset Health</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unlimited Attacks</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Reset Weapons</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Per Hedgehog Ammo</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Disable Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>More Wind</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Tag Team</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Add Bottom Border</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>binds</name>
    <message>
        <source>up</source>
        <translation>ylös</translation>
    </message>
    <message>
        <source>left</source>
        <translation>vasen</translation>
    </message>
    <message>
        <source>right</source>
        <translation>oikea</translation>
    </message>
    <message>
        <source>down</source>
        <translation>alas</translation>
    </message>
    <message>
        <source>attack</source>
        <translation>hyökkäys</translation>
    </message>
    <message>
        <source>precise aim</source>
        <translation>tarkka tähtäys</translation>
    </message>
    <message>
        <source>put</source>
        <translation>laita</translation>
    </message>
    <message>
        <source>switch</source>
        <translation>vaihto</translation>
    </message>
    <message>
        <source>find hedgehog</source>
        <translation>etsi siili</translation>
    </message>
    <message>
        <source>ammo menu</source>
        <translation>asevalikko</translation>
    </message>
    <message>
        <source>slot 1</source>
        <translation>Paikka 1</translation>
    </message>
    <message>
        <source>slot 2</source>
        <translation>Paikka 2</translation>
    </message>
    <message>
        <source>slot 3</source>
        <translation>Paikka 3</translation>
    </message>
    <message>
        <source>slot 4</source>
        <translation>Paikka 4</translation>
    </message>
    <message>
        <source>slot 5</source>
        <translation>Paikka 5</translation>
    </message>
    <message>
        <source>slot 6</source>
        <translation>Paikka 6</translation>
    </message>
    <message>
        <source>slot 7</source>
        <translation>Paikka 7</translation>
    </message>
    <message>
        <source>slot 8</source>
        <translation>Paikka 8</translation>
    </message>
    <message>
        <source>slot 9</source>
        <translation>Paikka 9</translation>
    </message>
    <message>
        <source>timer 1 sec</source>
        <translation>ajasta 1 sek</translation>
    </message>
    <message>
        <source>timer 2 sec</source>
        <translation>ajasta 2 sek</translation>
    </message>
    <message>
        <source>timer 3 sec</source>
        <translation>ajasta 3 sek</translation>
    </message>
    <message>
        <source>timer 4 sec</source>
        <translation>ajasta 4 sek</translation>
    </message>
    <message>
        <source>timer 5 sec</source>
        <translation>ajasta 5 sek</translation>
    </message>
    <message>
        <source>chat</source>
        <translation>keskustelu</translation>
    </message>
    <message>
        <source>chat history</source>
        <translation>keskusteluhistoria</translation>
    </message>
    <message>
        <source>pause</source>
        <translation>tauko</translation>
    </message>
    <message>
        <source>confirmation</source>
        <translation>varmistus</translation>
    </message>
    <message>
        <source>volume down</source>
        <translation>vähennä äänenvoimakkutta</translation>
    </message>
    <message>
        <source>volume up</source>
        <translation>lisää äänenvoimakkutta</translation>
    </message>
    <message>
        <source>change mode</source>
        <translation>vaihda tilaa</translation>
    </message>
    <message>
        <source>capture</source>
        <translation>kaappaa</translation>
    </message>
    <message>
        <source>hedgehogs
info</source>
        <translation>siilien
tiedot</translation>
    </message>
    <message>
        <source>quit</source>
        <translation>poistu</translation>
    </message>
    <message>
        <source>zoom in</source>
        <translation>lähennä</translation>
    </message>
    <message>
        <source>zoom out</source>
        <translation>loitonna</translation>
    </message>
    <message>
        <source>reset zoom</source>
        <translation>nollaa zoom</translation>
    </message>
    <message>
        <source>long jump</source>
        <translation>pitkä hyppy</translation>
    </message>
    <message>
        <source>high jump</source>
        <translation>korkea hyppy</translation>
    </message>
    <message>
        <source>slot 10</source>
        <translation>paikka 10</translation>
    </message>
</context>
<context>
    <name>binds (categories)</name>
    <message>
        <source>Basic controls</source>
        <translation>Peruskontrollit</translation>
    </message>
    <message>
        <source>Weapon controls</source>
        <translation>Asekontrollit</translation>
    </message>
    <message>
        <source>Camera and cursor controls</source>
        <translation>Kameran ja kursorin kontrollit</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Muu</translation>
    </message>
</context>
<context>
    <name>binds (descriptions)</name>
    <message>
        <source>Move your hogs and aim:</source>
        <translation>Liikuta siiliäsi ja tähtää:</translation>
    </message>
    <message>
        <source>Traverse gaps and obstacles by jumping:</source>
        <translation>Ylitä aukot ja esteet hyyppäämällä:</translation>
    </message>
    <message>
        <source>Fire your selected weapon or trigger an utility item:</source>
        <translation>Ammu valitulla aseella tai käytä apuvälinettä:</translation>
    </message>
    <message>
        <source>Pick a weapon or a target location under the cursor:</source>
        <translation>Valitse ase tai kohde kursorilla:</translation>
    </message>
    <message>
        <source>Switch your currently active hog (if possible):</source>
        <translation>Vaihda aktiivinen siili (jos mahdollista):</translation>
    </message>
    <message>
        <source>Pick a weapon or utility item:</source>
        <translation>Valitse ase tai apuväline:</translation>
    </message>
    <message>
        <source>Set the timer on bombs and timed weapons:</source>
        <translation>Ajasta pommi ja ajastetut aseet:</translation>
    </message>
    <message>
        <source>Move the camera to the active hog:</source>
        <translation>Liikuta kamera aktiivisen siilen luokse:</translation>
    </message>
    <message>
        <source>Move the cursor or camera without using the mouse:</source>
        <translation>Liikuta kursoria tai kameraa ilman hiirtä:</translation>
    </message>
    <message>
        <source>Modify the camera&apos;s zoom level:</source>
        <translation>Muuta kameran zoomausta:</translation>
    </message>
    <message>
        <source>Talk to your team or all participants:</source>
        <translation>Puhu joukkueellesi tai kaikille osanottajille:</translation>
    </message>
    <message>
        <source>Pause, continue or leave your game:</source>
        <translation>Tauota, jatka tai poistu pelistä:</translation>
    </message>
    <message>
        <source>Modify the game&apos;s volume while playing:</source>
        <translation>Vaihda pelin äänenvoimakkuutta pelin aikana:</translation>
    </message>
    <message>
        <source>Toggle fullscreen mode:</source>
        <translation>Vaihda kokonäyttö-tilaan/tilasta:</translation>
    </message>
    <message>
        <source>Take a screenshot:</source>
        <translation>Ota kuvankaappaus:</translation>
    </message>
    <message>
        <source>Toggle labels above hedgehogs:</source>
        <translation>Vaihda siilien yläpuolella näkyviä &quot;leimoja&quot;:</translation>
    </message>
</context>
<context>
    <name>binds (keys)</name>
    <message>
        <source>Axis</source>
        <translation>Akselit</translation>
    </message>
    <message>
        <source>(Up)</source>
        <translation>(Ylös)</translation>
    </message>
    <message>
        <source>(Down)</source>
        <translation>(Alas)</translation>
    </message>
    <message>
        <source>Hat</source>
        <translation>Hattu</translation>
    </message>
    <message>
        <source>(Left)</source>
        <translation>(Vasen)</translation>
    </message>
    <message>
        <source>(Right)</source>
        <translation>(Oikea)</translation>
    </message>
    <message>
        <source>Button</source>
        <translation>Nappi</translation>
    </message>
    <message>
        <source>Keyboard</source>
        <translation>Näppäimistö</translation>
    </message>
    <message>
        <source>Mouse: Middle button</source>
        <translation>Hiiri: Keskinappi</translation>
    </message>
    <message>
        <source>Mouse: Right button</source>
        <translation>Hiiri: Oikea nappi</translation>
    </message>
    <message>
        <source>Mouse: Wheel up</source>
        <translation>Hiiri: Rulla ylös</translation>
    </message>
    <message>
        <source>Mouse: Wheel down</source>
        <translation>Hiiri: Rulla alas</translation>
    </message>
    <message>
        <source>Backspace</source>
        <translation>Askelapalutin</translation>
    </message>
    <message>
        <source>Tab</source>
        <translation>Sarkain</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Tyhjennä</translation>
    </message>
    <message>
        <source>Return</source>
        <translation>Rivinvaihto</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>Tauko</translation>
    </message>
    <message>
        <source>Escape</source>
        <translation>Esc-näppäin</translation>
    </message>
    <message>
        <source>Space</source>
        <translation>Välilyönti</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Poistonäppäin</translation>
    </message>
    <message>
        <source>Numpad 0</source>
        <translation>Numpad 0</translation>
    </message>
    <message>
        <source>Numpad 1</source>
        <translation>Numpad 1</translation>
    </message>
    <message>
        <source>Numpad 2</source>
        <translation>Numpad 2</translation>
    </message>
    <message>
        <source>Numpad 3</source>
        <translation>Numpad 3</translation>
    </message>
    <message>
        <source>Numpad 4</source>
        <translation>Numpad 4</translation>
    </message>
    <message>
        <source>Numpad 5</source>
        <translation>Numpad 5</translation>
    </message>
    <message>
        <source>Numpad 6</source>
        <translation>Numpad 6</translation>
    </message>
    <message>
        <source>Numpad 7</source>
        <translation>Numpad 7</translation>
    </message>
    <message>
        <source>Numpad 8</source>
        <translation>Numpad 8</translation>
    </message>
    <message>
        <source>Numpad 9</source>
        <translation>Numpad 9</translation>
    </message>
    <message>
        <source>Numpad .</source>
        <translation>Numpad .</translation>
    </message>
    <message>
        <source>Numpad /</source>
        <translation>Numpad /</translation>
    </message>
    <message>
        <source>Numpad *</source>
        <translation>Numpad *</translation>
    </message>
    <message>
        <source>Numpad -</source>
        <translation>Numpad -</translation>
    </message>
    <message>
        <source>Numpad +</source>
        <translation>Numpad +</translation>
    </message>
    <message>
        <source>Enter</source>
        <translation>Rivinvaihto</translation>
    </message>
    <message>
        <source>Equals</source>
        <translation>=</translation>
    </message>
    <message>
        <source>Up</source>
        <translation>Ylös</translation>
    </message>
    <message>
        <source>Down</source>
        <translation>Alas</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Oikea</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Vasen</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Lisää-nappi</translation>
    </message>
    <message>
        <source>Home</source>
        <translation>Home-nappi</translation>
    </message>
    <message>
        <source>End</source>
        <translation>End-nappi</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>Sivu ylös</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>Sivu alas</translation>
    </message>
    <message>
        <source>Num lock</source>
        <translation>Num lock</translation>
    </message>
    <message>
        <source>Caps lock</source>
        <translation>Caps lock</translation>
    </message>
    <message>
        <source>Scroll lock</source>
        <translation>Scroll lock</translation>
    </message>
    <message>
        <source>Right shift</source>
        <translation>Oikea vaihtonäppäin</translation>
    </message>
    <message>
        <source>Left shift</source>
        <translation>Vasen vaihtonäppäin</translation>
    </message>
    <message>
        <source>Right ctrl</source>
        <translation>Oikea ctrl</translation>
    </message>
    <message>
        <source>Left ctrl</source>
        <translation>Vasen ctrl</translation>
    </message>
    <message>
        <source>Right alt</source>
        <translation>Oikea alt</translation>
    </message>
    <message>
        <source>Left alt</source>
        <translation>Vasen alt</translation>
    </message>
    <message>
        <source>Right meta</source>
        <translation>Oikea meta</translation>
    </message>
    <message>
        <source>Left meta</source>
        <translation>Vasen meta</translation>
    </message>
    <message>
        <source>A button</source>
        <translation>A-painike</translation>
    </message>
    <message>
        <source>B button</source>
        <translation>B-painike</translation>
    </message>
    <message>
        <source>X button</source>
        <translation>X-painike</translation>
    </message>
    <message>
        <source>Y button</source>
        <translation>Y-painike</translation>
    </message>
    <message>
        <source>LB button</source>
        <translation>LB-painike</translation>
    </message>
    <message>
        <source>RB button</source>
        <translation>RB-painike</translation>
    </message>
    <message>
        <source>Back button</source>
        <translation>Paluu-painike</translation>
    </message>
    <message>
        <source>Start button</source>
        <translation>Start-painike</translation>
    </message>
    <message>
        <source>Left stick</source>
        <translation>Vasen tikku</translation>
    </message>
    <message>
        <source>Right stick</source>
        <translation>Oikea tikku</translation>
    </message>
    <message>
        <source>Left stick (Right)</source>
        <translation>Vasen tikku (Oikea)</translation>
    </message>
    <message>
        <source>Left stick (Left)</source>
        <translation>Vasen tikku (Vasen)</translation>
    </message>
    <message>
        <source>Left stick (Down)</source>
        <translation>Vasen tikku (Alas)</translation>
    </message>
    <message>
        <source>Left stick (Up)</source>
        <translation>Vasen tikku (ylös)</translation>
    </message>
    <message>
        <source>Left trigger</source>
        <translation>Vasen liipasin</translation>
    </message>
    <message>
        <source>Right trigger</source>
        <translation>Oikea liipasin</translation>
    </message>
    <message>
        <source>Right stick (Down)</source>
        <translation>Oikea tikku (Alas)</translation>
    </message>
    <message>
        <source>Right stick (Up)</source>
        <translation>Oikea tikku (Ylös)</translation>
    </message>
    <message>
        <source>Right stick (Right)</source>
        <translation>Oikea tikku (Oikea)</translation>
    </message>
    <message>
        <source>Right stick (Left)</source>
        <translation>Oikea tikku (Vasen)</translation>
    </message>
    <message>
        <source>DPad</source>
        <translation>DPad</translation>
    </message>
    <message>
        <source>Mouse: Left button</source>
        <translation>Hiiri: Vasen nappi</translation>
    </message>
</context>
</TS>
